@@ -7,12 +7,12 @@ import random
 import time
 
 import bpy
-
+import mathutils
 
 from bpybb.utils import active_object, apply_rotation
 
 
-def time_seed():
+def time_seed() -> float:
     """
     Sets the random seed based on the time
     and copies the seed into the clipboard
@@ -26,14 +26,20 @@ def time_seed():
     return seed
 
 
-def apply_random_rotation():
+def get_random_rotation() -> mathutils.Euler:
+    """Returns a random Euler rotation on X, Y, Z"""
+    x = math.radians(random.uniform(0, 360))
+    y = math.radians(random.uniform(0, 360))
+    z = math.radians(random.uniform(0, 360))
+    return mathutils.Euler((x, y, z))
+
+
+def apply_random_rotation() -> None:
     """
     Applies a random rotation on X, Y, Z for the currently active object
     """
     obj = active_object()
 
-    obj.rotation_euler.x = math.radians(random.uniform(0, 360))
-    obj.rotation_euler.y = math.radians(random.uniform(0, 360))
-    obj.rotation_euler.z = math.radians(random.uniform(0, 360))
+    obj.rotation_euler = get_random_rotation()
 
     apply_rotation()
